==> webkit2gtk_2.45.3.orig.tar.xz: webkitgtk-2.45.3/Source/WebCore/Modules/mediasource/BufferedChangeEvent.h <==
/*
 * Copyright (C) 2023 Apple Inc. All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY APPLE INC. AND ITS CONTRIBUTORS ``AS IS''
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL APPLE INC. OR ITS CONTRIBUTORS
 * BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF
 * THE POSSIBILITY OF SUCH DAMAGE.
 */

#pragma once

#if ENABLE(MEDIA_SOURCE)

#include "Event.h"

namespace WebCore {

class TimeRanges;

class BufferedChangeEvent final : public Event {
    WTF_MAKE_ISO_ALLOCATED(BufferedChangeEvent);
public:
    ~BufferedChangeEvent();

    struct Init : EventInit {
        RefPtr<TimeRanges> addedRanges;
        RefPtr<TimeRanges> removedRanges;
    };

    static Ref<BufferedChangeEvent> create(RefPtr<TimeRanges>&& added, RefPtr<TimeRanges>&& removed)
    {
        return adoptRef(*new BufferedChangeEvent(WTFMove(added), WTFMove(removed)));
    }

    static Ref<BufferedChangeEvent> create(const AtomString& type, Init&& init)
    {
        return adoptRef(*new BufferedChangeEvent(type, WTFMove(init)));
    }

    RefPtr<TimeRanges> addedRanges() const;
    RefPtr<TimeRanges> removedRanges() const;

private:
    BufferedChangeEvent(RefPtr<TimeRanges>&& added, RefPtr<TimeRanges>&& removed);
    BufferedChangeEvent(const AtomString& type, Init&&);

    RefPtr<TimeRanges> m_added;
    RefPtr<TimeRanges> m_removed;
};

} // namespace WebCore

#endif // ENABLE(MEDIA_SOURCE)

==> webkit2gtk_2.50.4.orig.tar.xz: webkitgtk-2.50.4/Source/WebCore/Modules/mediasource/BufferedChangeEvent.h <==
/*
 * Copyright (C) 2023 Apple Inc. All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY APPLE INC. AND ITS CONTRIBUTORS ``AS IS''
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL APPLE INC. OR ITS CONTRIBUTORS
 * BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF
 * THE POSSIBILITY OF SUCH DAMAGE.
 */

#pragma once

#if ENABLE(MEDIA_SOURCE)

#include "Event.h"

namespace WebCore {

class TimeRanges;

class BufferedChangeEvent final : public Event {
    WTF_MAKE_TZONE_OR_ISO_ALLOCATED(BufferedChangeEvent);
public:
    ~BufferedChangeEvent();

    struct Init : EventInit {
        RefPtr<TimeRanges> addedRanges;
        RefPtr<TimeRanges> removedRanges;
    };

    static Ref<BufferedChangeEvent> create(RefPtr<TimeRanges>&& added, RefPtr<TimeRanges>&& removed)
    {
        return adoptRef(*new BufferedChangeEvent(WTFMove(added), WTFMove(removed)));
    }

    static Ref<BufferedChangeEvent> create(const AtomString& type, Init&& init)
    {
        return adoptRef(*new BufferedChangeEvent(type, WTFMove(init)));
    }

    RefPtr<TimeRanges> addedRanges() const;
    RefPtr<TimeRanges> removedRanges() const;

private:
    BufferedChangeEvent(RefPtr<TimeRanges>&& added, RefPtr<TimeRanges>&& removed);
    BufferedChangeEvent(const AtomString& type, Init&&);

    RefPtr<TimeRanges> m_added;
    RefPtr<TimeRanges> m_removed;
};

} // namespace WebCore

#endif // ENABLE(MEDIA_SOURCE)
